@@ -21,8 +21,8 @@ import numpy as np
 
 from multiprocessing import Process
 import multiprocessing
-from classlib import DScene, main_control, Weather
-from yolov5_onnx import mult_test
+from DParty.classlib import DScene, main_control, Weather
+from DParty.yolov5_onnx import mult_test
 
 # 返回对应两序号节点的向量（数对）
 def backvector(list,n,m):
